# framework

## idea
- [ ] TUI for a monitoring system / CLI for project commands
- [ ] Set **static** Config to .yaml or .ini (.conf, .cfg, etc...)
- [ ] Cli command API output mode for postman

### TODO:
- [ ] Database core 
   - [ ] NoSQL
   - [x] SQL
- [x] Url core
- [ ] HTML Rendering
- [ ] CronJob (Optional)
- [ ] Signal core (models, query, view, ...)
- [ ] View core --> (actors, views, apis, controllers, ...)
- [ ] Middleware core
- [x] Serializer --> Serpyco
- [ ] Test --> Pytest
- [ ] Websocket core
- [ ] Jinja
- [ ] Load config file in config of framework
- [ ] Database Driver
- [ ] User strawberry.rocks for GraphQL